@@ -40,14 +40,14 @@
             Sao.rpc({
                 'method': 'wizard.' + this.action + '.create',
                 'params': [this.session.context]
-            }, this.session).then(function(result) {
+            }, this.session).then(result => {
                 this.session_id = result[0];
                 this.start_state = this.state = result[1];
                 this.end_state = result[2];
                 this.process();
-            }.bind(this), function() {
+            }, () => {
                 this.destroy();
-            }.bind(this));
+            });
         },
         process: function() {
             if (this.__processing || this.__waiting_response) {
@@ -66,17 +66,22 @@
                 Sao.rpc({
                     'method': 'wizard.' + this.action + '.execute',
                     'params': [this.session_id, data, this.state, ctx]
-                }, this.session).then(function(result) {
+                }, this.session).then(result => {
                     if (result.view) {
                         this.clean();
                         var view = result.view;
                         this.update(view.fields_view, view.buttons);
 
-                        this.screen.new_(false).then(function() {
-                            this.screen.current_record.set_default(view.defaults);
-                            this.update_buttons();
-                            this.screen.set_cursor();
-                        }.bind(this));
+                        this.screen.new_(false).then(() => {
+                            this.screen.current_record.set_default(
+                                view.defaults || {})
+                                .then(() => {
+                                    this.screen.current_record.set(
+                                        view.values || {});
+                                    this.update_buttons();
+                                    this.screen.set_cursor();
+                                });
+                        });
 
                         this.screen_state = view.state;
                         this.__waiting_response = true;
@@ -84,9 +89,9 @@
                         this.state = this.end_state;
                     }
 
-                    var execute_actions = function execute_actions() {
+                    const execute_actions = () => {
                         if (result.actions) {
-                            result.actions.forEach(function(action) {
+                            for (const action of result.actions) {
                                 var context = jQuery.extend({}, this.context);
                                 // Remove wizard keys added by run
                                 delete context.active_id;
@@ -95,9 +100,9 @@
                                 delete context.action_id;
                                 Sao.Action.execute(
                                     action[0], action[1], context);
-                            }.bind(this));
+                            }
                         }
-                    }.bind(this);
+                    };
 
                     if (this.state == this.end_state) {
                         this.end().then(execute_actions);
@@ -105,10 +110,10 @@
                         execute_actions();
                     }
                     this.__processing = false;
-                }.bind(this), function(result) {
+                }, result => {
                     // TODO end for server error.
                     this.__processing = false;
-                }.bind(this));
+                });
             };
             process.call(this);
         },
@@ -119,9 +124,14 @@
             return Sao.rpc({
                 'method': 'wizard.' + this.action + '.delete',
                 'params': [this.session_id, this.session.context]
-            }, this.session).then(function(action) {
+            }, this.session).then(action => {
                 this.destroy(action);
-            }.bind(this));
+            })
+            .fail(() => {
+                Sao.Logger.warn(
+                    "Unable to delete session %s of wizard %s",
+                    this.session_id, this.action);
+            });
         },
         clean: function() {
             this.widget.empty();
@@ -133,11 +143,10 @@
             if (definition.validate && !this.screen.current_record.validate(
                     null, null, null, true)) {
                 this.screen.display(true);
-                this.info_bar.message(
-                    this.screen.invalid_message(), 'danger');
+                this.info_bar.add(this.screen.invalid_message(), 'danger');
                 return;
             }
-            this.info_bar.message();
+            this.info_bar.clear();
             this.state = definition.state;
             this.process();
         },
@@ -153,6 +162,10 @@
             this.states[definition.state] = button;
             return button;
         },
+        record_modified: function() {
+            this.update_buttons();
+            this.info_bar.refresh();
+        },
         update_buttons: function() {
             var record = this.screen.current_record;
             for (var state in this.states) {
@@ -161,14 +174,18 @@
             }
         },
         update: function(view, buttons) {
-            buttons.forEach(function(button) {
+            for (const button of buttons) {
                 this._get_button(button);
-            }.bind(this));
+            }
+            if (this.screen) {
+                this.screen.windows.splice(
+                    this.screen.windows.indexOf(this), 1);
+            }
             this.screen = new Sao.Screen(view.model,
                     {mode: [], context: this.context});
             this.screen.add_view(view);
             this.screen.switch_view();
-            this.screen.group_changed_callback = this.update_buttons.bind(this);
+            this.screen.windows.push(this);
             this.header.append(jQuery('<h4/>', {
                 'class': 'model-title',
                 'title': this.name,
@@ -213,9 +230,9 @@
             var button = Sao.Wizard.Form._super._get_button.call(this,
                 definition);
             this.footer.append(button.el);
-            button.el.click(function() {
+            button.el.click(() => {
                 this.response(definition);
-            }.bind(this));
+            });
             return button;
         },
         destroy: function(action) {
@@ -233,9 +250,8 @@
             }
         },
         end: function() {
-            return Sao.Wizard.Form._super.end.call(this).always(function() {
-                return this.tab.close();
-            }.bind(this));
+            return Sao.Wizard.Form._super.end.call(this).always(
+                () => this.tab.close());
         }
     });
 
@@ -247,14 +263,14 @@
             this.header = dialog.header;
             this.content = dialog.content;
             this.footer = dialog.footer;
-            this.dialog.on('keydown', function(e) {
+            this.dialog.on('keydown', e => {
                 if (e.which == Sao.common.ESC_KEYCODE) {
                     e.preventDefault();
                     if (this.end_state in this.states) {
                         this.response(this.states[this.end_state].attributes);
                     }
                 }
-            }.bind(this));
+            });
             dialog.body.append(this.widget).append(this.info_bar.el);
         },
         clean: function() {
@@ -268,15 +284,15 @@
             this.footer.append(button.el);
             if (definition['default']) {
                 this.content.unbind('submit');
-                this.content.submit(function(e) {
+                this.content.submit(e => {
                     this.response(definition);
                     e.preventDefault();
-                }.bind(this));
+                });
                 button.el.attr('type', 'submit');
             } else {
-                button.el.click(function() {
+                button.el.click(() => {
                     this.response(definition);
-                }.bind(this));
+                });
             }
             return button;
         },
@@ -287,7 +303,7 @@
         },
         destroy: function(action) {
             Sao.Wizard.Dialog._super.destroy.call(this, action);
-            var destroy = function() {
+            const destroy = () => {
                 this.dialog.remove();
                 var dialog = jQuery('.wizard-dialog').filter(':visible')[0];
                 var is_menu = false;
@@ -323,7 +339,7 @@
                         });
                     }
                 }
-            }.bind(this);
+            };
             if ((this.dialog.data('bs.modal') || {}).isShown) {
                 this.dialog.on('hidden.bs.modal', destroy);
                 this.dialog.modal('hide');
@@ -337,11 +353,9 @@
             if (view.view_type == 'form') {
                 expand = false;
                 var fields = view.get_fields();
-                for (var i = 0; i < fields.length; i++) {
-                    var name = fields[i];
+                for (const name of fields) {
                     var widgets = view.widgets[name];
-                    for (var j = 0; j < widgets.length; j++) {
-                        var widget = widgets[j];
+                    for (const widget of widgets) {
                         if (widget.expand) {
                             expand = true;
                             break;
